@@ -23,13 +23,17 @@ def fix_field_typos(paragraph):
             continue
         for option in valid_field_names:
             if distance(field, option) == 1:
-                paragraph[option] = paragraph[field]
+                value = paragraph[field]
                 del paragraph[field]
+                paragraph[option] = value
                 fixed = True
                 break
 
 
-update_deb822('debian/copyright', paragraph_cb=fix_field_typos)
+try:
+    update_deb822('debian/copyright', paragraph_cb=fix_field_typos)
+except FileNotFoundError:
+    pass
 
 
 print('Fix field name typos in debian/copyright.')
