@@ -49,7 +49,7 @@ from debian.deb822 import Deb822
 from .reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 52)
+__version__ = (0, 53)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'confident', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -617,6 +617,9 @@ def all_sha_prefixed(cl):
     return (sha_prefixed > 0)
 
 
+_changelog_policy_noted = False
+
+
 def guess_update_changelog(tree, path='', cl=None):
     """Guess whether the changelog should be updated.
 
@@ -624,9 +627,12 @@ def guess_update_changelog(tree, path='', cl=None):
       tree: Tree to edit
       path: Path to packaging in tree
     """
+    global _changelog_policy_noted
     if gbp_conf_has_dch_section(tree, path):
-        note('Assuming changelog does not need to be updated, '
-             'since there is a [dch] section in gbp.conf.')
+        if not _changelog_policy_noted:
+            note('Assuming changelog does not need to be updated, '
+                 'since there is a [dch] section in gbp.conf.')
+            _changelog_policy_noted = True
         return False
 
     # TODO(jelmes): Do something more clever here, perhaps looking at history
